@@ -1,5 +1,5 @@
 /* cmds.c -- Texinfo commands.
-   $Id: cmds.c,v 1.43 2004/03/08 22:46:38 karl Exp $
+   $Id: cmds.c,v 1.44 2004/03/14 22:47:19 karl Exp $
 
    Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Free Software
    Foundation, Inc.
@@ -653,6 +653,7 @@ void
 cm_acronym (int arg)
 {
   char *acronym, *description;
+  unsigned len;
 
   /* We do everything at START.  */
   if (arg == END)
@@ -680,8 +681,10 @@ cm_acronym (int arg)
   /* Get description out of braces.  */
   if (description[0] == '{')
     description++;
-  if (description[strlen (description)-1] == '}')
-    description[strlen (description)-1] = '\0';
+
+  len = strlen (description);
+  if (len && description[len-1] == '}')
+    description[len-1] = '\0';
 
   /* Save new description.  */
   if (strlen (description) > 0)
